@@ -92,7 +92,7 @@ class Admin:
             conn.close()
 
     @staticmethod
-    def initdb(database: str, url: str, user: str = None, password: str = None):
+    def initdb(database: str, url: str, user: str = None, password: str = None, omop=False):
         """Initialize the new db for the project
 
         The omop vocabulary tables are populated during this process. It may take some time.
@@ -104,6 +104,8 @@ as jdbc:database_type//host:port/dbname) used to generate the project id
             user (:obj:`str`, optional): a username of choice.
             password (:obj:`str`, optional): a password of choice. If not specified, \
 the command will prompt for a password
+            omop (:obj:`bool`, optional): If specified, The omop vocabulary tables will be \
+            populated during this process. It may take some time.
         """
 
         try:
@@ -143,10 +145,13 @@ the command will prompt for a password
                     curs.execute(user_stmt, (password,))
                     log.info("Initializing the project database...")
                     curs.execute(initdb_stmt)
-                    log.info("Loading OMOP vocabulary tables...")
-                    for template in OMOP_TEMPLATES:
-                        omop_stmt = JINJA_ENV.get_template(template).render(schema=OMOP_DBT_SCHEMA)
-                        curs.execute(omop_stmt)
+                    if omop:
+                        log.info("Loading OMOP vocabulary tables...")
+                        for template in OMOP_TEMPLATES:
+                            omop_stmt = JINJA_ENV.get_template(template).render(
+                                schema=OMOP_DBT_SCHEMA
+                            )
+                            curs.execute(omop_stmt)
                     set_search_path_stmt = sql.SQL("SET search_path TO {dbt_schema}").format(
                         dbt_schema=sql.Identifier(DBT_SCHEMA)
                     )
@@ -159,6 +164,33 @@ the command will prompt for a password
         finally:
             conn.close()
 
+    @staticmethod
+    def add_omop_vocab(database: str):
+        """Add omop vocabulary tables
+
+        Args:
+            database (str): the target database
+        """
+        conn = connect(
+            host=POSTGRES_HOST,
+            dbname=database,
+            port=POSTGRES_PORT,
+            user=POSTGRES_USER,
+            password=POSTGRES_PASSWORD,
+        )
+
+        try:
+            with conn:
+                with conn.cursor() as curs:
+                    log.info("Loading OMOP vocabulary tables...")
+                    for template in OMOP_TEMPLATES:
+                        omop_stmt = JINJA_ENV.get_template(template).render(schema=OMOP_DBT_SCHEMA)
+                        curs.execute(omop_stmt)
+        except Exception as e:
+            log.error(e)
+        finally:
+            conn.close()
+
     @staticmethod
     def connect(database: str):
         """Add a Kafka Connect connector
@@ -193,7 +225,7 @@ the command will prompt for a password
         Args:
             target (str): the target database
             source (str): the source database
-            type (str): the source database type (can be either `oracle` or `postgres`)
+            type (str): the source database type (can be either `oracle`, `postgres` or `tds`)
             host (str): the source server host
             port (int): the source server port
             user (str): a source database user
