@@ -1,4 +1,4 @@
-from typing import Iterator, Tuple
+from typing import Iterator
 
 import fire
 from colorama import Fore, deinit, init
@@ -27,10 +27,10 @@ from utils.number_print import number_print
 CURSOR_ITERSIZE = 20
 
 
-def get_resources_from_model(
+def get_fhir_resources_from_model(
     cursor, model: str, offset: int = 0, limit: int = 100
 ) -> Iterator[dict]:
-    """get_resources_from_model looks for a fhir model file and retrieves the Fhir resources
+    """get_fhir_resources_from_model looks for a fhir model file and retrieves the Fhir resources
 
     This function uses a named cursor fetching at most CURSOR_ITERSIZE rows
     at each network roundtrip during iteration on the cursor
@@ -61,7 +61,7 @@ class Cli:
         self.admin = Admin()
 
     @staticmethod
-    def link(source: str, include: Tuple[str] = None, exclude: Tuple[str] = None):
+    def link(source: str, include: tuple[str] = None, exclude: tuple[str] = None):
         """Create a foreign schema from a schema of the source database
 
         This command uses a foreign data wrapper to access data
@@ -72,12 +72,12 @@ class Cli:
 
         Args:
             source (str): the source schema
-            include (:obj:`tuple` of :obj:`str`, optional): comma separated table names to import
-                only foreign tables matching one of the given table names. Other tables existing in
-                the foreign schema will be ignored.
-            exclude (:obj:`tuple` of :obj:`str`, optional): comma separated table names to exclude
-                specified  foreign tables from the import. All tables existing in the foreign
-                schema will be imported except the ones listed here.
+            include (:obj:`tuple` of :obj:`str`, optional): comma separated table names to import \
+only foreign tables matching one of the given table names. Other tables existing in \
+the foreign schema will be ignored.
+            exclude (:obj:`tuple` of :obj:`str`, optional): comma separated table names to exclude \
+specified  foreign tables from the import. All tables existing in the foreign \
+schema will be imported except the ones listed here.
         """
 
         if include and exclude:
@@ -92,12 +92,18 @@ class Cli:
             password=POSTGRES_PASSWORD,
         )
 
-        with conn.cursor() as curs:
-            db_type_stmt = sql.SQL("SELECT db_type FROM {dbt_meta_table}").format(
-                dbt_meta_table=sql.Identifier(DBT_SCHEMA, DBT_META_TABLE)
-            )
-            curs.execute(db_type_stmt)
-            (db_type) = curs.fetchone()
+        try:
+            with conn:
+                with conn.cursor() as curs:
+                    db_type_stmt = sql.SQL("SELECT db_type FROM {dbt_meta_table}").format(
+                        dbt_meta_table=sql.Identifier(DBT_SCHEMA, DBT_META_TABLE)
+                    )
+                    curs.execute(db_type_stmt)
+                    db_type = curs.fetchone()
+        except Exception as e:
+            conn.close()
+            log.error(e)
+            return
 
         schema_stmt = sql.SQL("CREATE SCHEMA IF NOT EXISTS {schema}").format(
             schema=sql.Identifier(source)
@@ -126,12 +132,15 @@ class Cli:
             "{options}"
         ).format(constraints=constraints, options=options, schema=sql.Identifier(source))
 
-        with conn.cursor() as curs:
-            curs.execute(schema_stmt)
-            curs.execute(import_stmt)
-            conn.commit()
-
-        conn.close()
+        try:
+            with conn:
+                with conn.cursor() as curs:
+                    curs.execute(schema_stmt)
+                    curs.execute(import_stmt)
+        except Exception as e:
+            log.error(e)
+        finally:
+            conn.close()
 
     @staticmethod
     def validate(model: str, offset: int = 0, limit: int = 100):
@@ -153,29 +162,32 @@ class Cli:
             options=f"-c search_path={DBT_SCHEMA}",
         )
         cursor = conn.cursor(name="curname")
-        cursor.itersize = CURSOR_ITERSIZE
         try:
             # Function in order to filter ANSI escape sequences on Windows
             # see https://pypi.org/project/colorama/
             init(autoreset=True)
-            for resource in get_resources_from_model(cursor, model, offset, limit):
-                fhir = FhirResource(resource)
-                number_print(repr(fhir))
-                try:
-                    fhir.validate()
-                    log.info(f"{Fore.GREEN}✅ FHIR resource is valid")
-                except FhirValidationError as e:
-                    log.error(f"{Fore.RED}❌ FHIR resource is not valid\n{e}")
-                input("Press [Return] for the next result or [Ctrl+c] to quit")
+            with conn:
+                with cursor:
+                    cursor.itersize = CURSOR_ITERSIZE
+                    for resource in get_fhir_resources_from_model(cursor, model, offset, limit):
+                        fhir = FhirResource(resource)
+                        number_print(repr(fhir))
+                        try:
+                            fhir.validate()
+                            # The message will be printed in GREEN, hence the weird sequence
+                            # at the beginning and at the end
+                            log.info(f"{Fore.GREEN}✅ FHIR resource is valid")
+                        except FhirValidationError as e:
+                            # Same as above
+                            log.error(f"{Fore.RED}❌ FHIR resource is not valid\n{e}")
+                        input("Press [Return] for the next result or [Ctrl+c] to quit")
         except ProgrammingError as e:
-            conn.rollback()
             log.error(e)
         except HTTPError as e:
             log.error(e.response.json())
         except KeyboardInterrupt:
             pass
         finally:
-            cursor.close()
             conn.close()
             # Stop using Colorama
             # see https://pypi.org/project/colorama/
